package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````$"D```````!``````````%C!````
M`````````$``.``-`$``'0`<``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````*@9````````J!D`````````
M$`````````$````%`````"``````````(``````````@````````K4(`````
M``"M0@`````````0`````````0````0`````<`````````!P`````````'``
M``````!(2````````$A(`````````!`````````!````!@```,B[````````
MR,L```````#(RP```````&`$````````B`0`````````$`````````(````&
M````V+L```````#8RP```````-C+``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````P````````
M`#``````````"``````````$````!````&@#````````:`,```````!H`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````,``````````P``````````@`````````4.5T9`0`
M``#`L````````,"P````````P+`````````$`0````````0!````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````R+L```````#(RP```````,C+````
M````.`0````````X!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````(`````4```!'3E4``@``P`0````#````````
M``*``,`$`````0`````````$````%`````,```!'3E4`37P;2":]MJ6`7I)(
MU;$]GWPL&!H$````$`````$```!'3E4```````,````"```````````````1
M````0P````0````(````(!`0``5`!(0H`@`$@(8`A(*)``()(`0(B(`10;H`
M`@@`````0P```$8```!)````2@```%(```!3````5`````````!6````5P``
M`%@```!9````6P```%T``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#FVL)0]9G
MK\QF0D75[(D'<-,S8MOM%8PES`TZEPM^J9R;T67.;>"G`@IK&IY0H^#[20``
M`````````````````````````````*$"```2````````````````````````
M``@"```2`````````````````````````(P````1````````````````````
M`````(@"```2`````````````````````````#X!```2````````````````
M`````````.,!```2`````````````````````````$0"```2````````````
M``````````````$````@`````````````````````````*P!```2````````
M`````````````````&<````2`````````````````````````+D!```2````
M`````````````````````)0````2`````````````````````````($"```2
M`````````````````````````-,"```2`````````````````````````/@!
M```2`````````````````````````-(````2````````````````````````
M`.(````2`````````````````````````#`!```2````````````````````
M`````&0!```2`````````````````````````(H````1````````````````
M`````````'8#```2`````````````````````````!`````@````````````
M`````````````+D"```2`````````````````````````*8"```2````````
M`````````````````+T````2`````````````````````````"P````@````
M`````````````````````)T````2`````````````````````````*L````2
M`````````````````````````)T!```2`````````````````````````*L"
M```2`````````````````````````.@````6````````````````````````
M`/L````2`````````````````````````%<"```2````````````````````
M`````!8!```2`````````````````````````,0"```2````````````````
M`````````(X!```2`````````````````````````/$!```2````````````
M`````````````,4!```2`````````````````````````$4!```2````````
M`````````````````"<!```2`````````````````````````%0!```2````
M`````````````````````'(!```2`````````````````````````),"```2
M`````````````````````````-(!```2`````````````````````````'D!
M```2`````````````````````````"D"```2````````````````````````
M`'D````2`````````````````````````(<!```2````````````````````
M`````(`!```2`````````````````````````)P````2````````````````
M`````````+X!```2`````````````````````````!0"```2````````````
M`````````````'4"```2`````````````````````````+$!```2````````
M`````````````````-D````2`````````````````````````,0````2````
M`````````````````````)8!```1`````````````````````````&@"```1
M`````````````````````````*0````2`````````````````````````%P!
M```2``````````````````````````L!```2````````````````````````
M`#4"```2`````````````````````````%4````2````````````````````
M`````&L!```2`````````````````````````+,````2````````````````
M`````````,P!```2`````````````````````````'\#```2`!``8%T`````
M``#;`````````-0#```2`!``0%0```````#T!@```````&(````2`!```"<`
M```````.`@```````/8"```2`!``T$<````````)`````````!0#```2`!``
M0%L````````@`@```````/H#```2`!``X$<````````2`@```````+H#```0
M`!H`*-````````````````````<#```2`!```$H````````F`````````"H#
M```2`!``D%````````!I`````````(L#```1`!(``'`````````$````````
M`*<#```2`!``D%X```````"?`0```````+(#```2`!``P$8````````I````
M`````,\#```0`!H`4-```````````````````.@#```2`!``,%,````````+
M`0```````!$$```2`!```%$```````"^`````````)H#```0`!D``-``````
M`````````````$X#```2`!``,$H```````!!`0```````.$#```0`!D`*-``
M``````````````````<$```1`!D`(-`````````(`````````*`#```2`!``
M$"D````````F`````````,8#```2`!``0%X```````!)`````````)P#```@
M`!D``-```````````````````&0#```2`!```%,````````A`````````$8`
M```B`````````````````````````#@#```2`!``\$8```````#3````````
M`%H#```2`!``,&````````!5`@```````!D$```2`!``@$L````````$!0``
M``````!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!?7V-X85]F:6YA;&EZ90!?
M7VQI8F-?<W1A<G1?;6%I;@!?7W)E9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H
M:U]F86EL`%]?96YV:7)O;@!S=')N8VUP`&QS=&%T-C0`86-C97-S`&]P96YD
M:7(`<F5A9&1I<C8T`'-T<FQE;@!?7W-P<FEN=&9?8VAK`'5N;&EN:P!C;&]S
M961I<@!R;61I<@!03%]C=7)R96YT7V-O;G1E>'0`8F]O=%]$>6YA3&]A9&5R
M`%!E<FQ?;F5W6%,`4&5R;%]N97=84U]F;&%G<P!R96%D;&EN:P!097)L7W-V
M7W-E='!V`&UE;6-H<@!097)L7W-V7W-E='!V;@!M96UM;W9E`')E86QL;V,`
M9V5T<&ED`&UE;6-P>0!S=')C:'(`<W1R9'5P`'-T<G1O:P!S=')C;7``<W1R
M<F-H<@!S=&1E<G(`7U]V9G!R:6YT9E]C:&L`97AI=`!L<V5E:S8T`')E860`
M9V5T=6ED`'-T<G-T<@!M:V1I<@!?7V5R<FYO7VQO8V%T:6]N`%]?9G!R:6YT
M9E]C:&L`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP=@!097)L7V=E=%]S=@!097)L
M7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L7W-Y<U]I;FET,P!0
M97)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U;F1U
M;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?<&%R<V4`<&5R;%]D97-T<G5C
M=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V%L;&]C`'!E<FQ?8V]N
M<W1R=6-T`'!E<FQ?<G5N`&QI8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`<&%R
M7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"
M3T]4`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D
M:7)N86UE`'-H85]F:6YA;`!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P
M87)?8VQE86YU<`!?24]?<W1D:6Y?=7-E9`!?7V1A=&%?<W1A<G0`<VAA7W5P
M9&%T90!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK
M=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`
M;7E?<&%R7W!L`'!A<E]D:64`<&%R7VEN:71?96YV`$=,24)#7S(N,30`1TQ)
M0D-?,BXS-`!'3$E"0U\R+C0`1TQ)0D-?,BXS,P!'3$E"0U\R+C,N,@!'3$E"
M0U\R+C,N-`!'3$E"0U\R+C(N-0`````!``$``@`!``(``P`!``$``@`$``(`
M`@`"``$``0`"``(``0`"``(``@`!``$``@`"``$`!0`"``,``0`!``$``0`!
M``$``@`"``(``0`"``(``@`!``(``@`!``8``@`"``4``@`!``$``@`"``,`
M`@`!``(``@`!``$`!P`(``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``@`!``$``0`````````!``<`[`(``!``
M````````E)&6!@``"``F!```$````+21E@8```<`,00``!`````4:6D-```&
M`#P$```0````LY&6!@``!0!&!```$````'(9:0D```0`400``!````!T&6D)
M```#`%T$```0````=1II"0```@!I!````````,C+````````"`````````#P
M*0```````-#+````````"`````````"P*0````````C0````````"```````
M```(T````````"#0````````"`````````#X<@```````*#/````````!@``
M``,``````````````*C/````````!@````<``````````````+#/````````
M!@````@``````````````+C/````````!@```!8``````````````,#/````
M````!@```!H``````````````,C/````````!@```%H``````````````-#/
M````````$@```!\``````````````-C/````````!@```"``````````````
M`.#/````````!@```"$``````````````.C/````````!@```#D`````````
M`````/#/````````!@```#H``````````````/C/````````!@```#\`````
M`````````/#-````````!P````$``````````````/C-````````!P````(`
M``````````````#.````````!P````0```````````````C.````````!P``
M``4``````````````!#.````````!P````8``````````````!C.````````
M!P````D``````````````"#.````````!P````H``````````````"C.````
M````!P````L``````````````##.````````!P````P``````````````#C.
M````````!P````T``````````````$#.````````!P````X`````````````
M`$C.````````!P````\``````````````%#.````````!P```!``````````
M`````%C.````````!P```!$``````````````&#.````````!P```!(`````
M`````````&C.````````!P```!,``````````````'#.````````!P```!4`
M`````````````'C.````````!P```!<``````````````(#.````````!P``
M`!@``````````````(C.````````!P```!D``````````````)#.````````
M!P```!L``````````````)C.````````!P```!P``````````````*#.````
M````!P```!T``````````````*C.````````!P```!X``````````````+#.
M````````!P```"(``````````````+C.````````!P```",`````````````
M`,#.````````!P```"0``````````````,C.````````!P```"4`````````
M`````-#.````````!P```"8``````````````-C.````````!P```"<`````
M`````````.#.````````!P```"@``````````````.C.````````!P```"D`
M`````````````/#.````````!P```"H``````````````/C.````````!P``
M`"L```````````````#/````````!P```"P```````````````C/````````
M!P```"T``````````````!#/````````!P```"X``````````````!C/````
M````!P```"\``````````````"#/````````!P```#```````````````"C/
M````````!P```#$``````````````##/````````!P```#(`````````````
M`#C/````````!P```#,``````````````$#/````````!P```#0`````````
M`````$C/````````!P```#4``````````````%#/````````!P```#8`````
M`````````%C/````````!P```#<``````````````&#/````````!P```#@`
M`````````````&C/````````!P```#L``````````````'#/````````!P``
M`#P``````````````'C/````````!P```#T``````````````(#/````````
M!P```#X``````````````(C/````````!P```$```````````````)#/````
M````!P```$$``````````````)C/````````!P```$(`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!:&O``!(A<!T`O_02(/$",,``````/\UNJT``/\EO*T`
M``\?0`#S#Q[Z:`````#IXO___V:0\P\>^F@!````Z=+___]FD/,/'OIH`@``
M`.G"____9I#S#Q[Z:`,```#ILO___V:0\P\>^F@$````Z:+___]FD/,/'OIH
M!0```.F2____9I#S#Q[Z:`8```#I@O___V:0\P\>^F@'````Z7+___]FD/,/
M'OIH"````.EB____9I#S#Q[Z:`D```#I4O___V:0\P\>^F@*````Z4+___]F
MD/,/'OIH"P```.DR____9I#S#Q[Z:`P```#I(O___V:0\P\>^F@-````Z1+_
M__]FD/,/'OIH#@```.D"____9I#S#Q[Z:`\```#I\O[__V:0\P\>^F@0````
MZ>+^__]FD/,/'OIH$0```.G2_O__9I#S#Q[Z:!(```#IPO[__V:0\P\>^F@3
M````Z;+^__]FD/,/'OIH%````.FB_O__9I#S#Q[Z:!4```#IDO[__V:0\P\>
M^F@6````Z8+^__]FD/,/'OIH%P```.ER_O__9I#S#Q[Z:!@```#I8O[__V:0
M\P\>^F@9````Z5+^__]FD/,/'OIH&@```.E"_O__9I#S#Q[Z:!L```#I,O[_
M_V:0\P\>^F@<````Z2+^__]FD/,/'OIH'0```.D2_O__9I#S#Q[Z:!X```#I
M`O[__V:0\P\>^F@?````Z?+]__]FD/,/'OIH(````.GB_?__9I#S#Q[Z:"$`
M``#ITOW__V:0\P\>^F@B````Z<+]__]FD/,/'OIH(P```.FR_?__9I#S#Q[Z
M:"0```#IHOW__V:0\P\>^F@E````Z9+]__]FD/,/'OIH)@```.F"_?__9I#S
M#Q[Z:"<```#I<OW__V:0\P\>^F@H````Z6+]__]FD/,/'OIH*0```.E2_?__
M9I#S#Q[Z:"H```#I0OW__V:0\P\>^F@K````Z3+]__]FD/,/'OIH+````.DB
M_?__9I#S#Q[Z:"T```#I$OW__V:0\P\>^F@N````Z0+]__]FD/,/'OIH+P``
M`.GR_/__9I#S#Q[Z:#````#IXOS__V:0\P\>^F@Q````Z=+\__]FD/,/'OIH
M,@```.G"_/__9I#S#Q[Z:#,```#ILOS__V:0\P\>^F@T````Z:+\__]FD/,/
M'OIH-0```.F2_/__9I#S#Q[Z_R4NK```9@\?1```\P\>^O\E1JH``&8/'T0`
M`/,/'OK_)3ZJ``!F#Q]$``#S#Q[Z_R4VJ@``9@\?1```\P\>^O\E+JH``&8/
M'T0``/,/'OK_)2:J``!F#Q]$``#S#Q[Z_R4>J@``9@\?1```\P\>^O\E%JH`
M`&8/'T0``/,/'OK_)0ZJ``!F#Q]$``#S#Q[Z_R4&J@``9@\?1```\P\>^O\E
M_JD``&8/'T0``/,/'OK_)?:I``!F#Q]$``#S#Q[Z_R7NJ0``9@\?1```\P\>
M^O\EYJD``&8/'T0``/,/'OK_)=ZI``!F#Q]$``#S#Q[Z_R76J0``9@\?1```
M\P\>^O\ESJD``&8/'T0``/,/'OK_)<:I``!F#Q]$``#S#Q[Z_R6^J0``9@\?
M1```\P\>^O\EMJD``&8/'T0``/,/'OK_):ZI``!F#Q]$``#S#Q[Z_R6FJ0``
M9@\?1```\P\>^O\EGJD``&8/'T0``/,/'OK_)9:I``!F#Q]$``#S#Q[Z_R6.
MJ0``9@\?1```\P\>^O\EAJD``&8/'T0``/,/'OK_)7ZI``!F#Q]$``#S#Q[Z
M_R5VJ0``9@\?1```\P\>^O\E;JD``&8/'T0``/,/'OK_)6:I``!F#Q]$``#S
M#Q[Z_R5>J0``9@\?1```\P\>^O\E5JD``&8/'T0``/,/'OK_)4ZI``!F#Q]$
M``#S#Q[Z_R5&J0``9@\?1```\P\>^O\E/JD``&8/'T0``/,/'OK_)3:I``!F
M#Q]$``#S#Q[Z_R4NJ0``9@\?1```\P\>^O\E)JD``&8/'T0``/,/'OK_)1ZI
M``!F#Q]$``#S#Q[Z_R46J0``9@\?1```\P\>^O\E#JD``&8/'T0``/,/'OK_
M)0:I``!F#Q]$``#S#Q[Z_R7^J```9@\?1```\P\>^O\E]J@``&8/'T0``/,/
M'OK_)>ZH``!F#Q]$``#S#Q[Z_R7FJ```9@\?1```\P\>^O\EWJ@``&8/'T0`
M`/,/'OK_)=:H``!F#Q]$``#S#Q[Z_R7.J```9@\?1```\P\>^O\EQJ@``&8/
M'T0``/,/'OK_);ZH``!F#Q]$``#S#Q[Z_R6VJ```9@\?1```\P\>^O\EKJ@`
M`&8/'T0``/,/'OK_)::H``!F#Q]$``#S#Q[Z_R6>J```9@\?1```\P\>^E53
M2(/L.(E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H````2(E$
M)"@QP.B$____2(LU9:@``$B+/9:H``!(B?+H/CL``$B+!9>H``"`.``/A!@!
M``!(BP5GJ```9$B+`("(*@0```.+1"0<C7@$C5@#2&/_2,'G`^C&_O__2(M,
M)!!$BT0D'$B)QDB)!:JH``!(BP%(B09(C04\2@``2(E&"$B-!6JH``!(BP!(
MB4802(T%)DH``$B)1AA!@_@!#XXC`0``2(/!"$&#P`.X!````)!(BSE(8]"#
MP`%(@\$(2(D\UD0YP'7J2)A(BSTYJ```13'`2(GQ2,<$Q@````")VDB--2H;
M``#HI?O__X7`#X2'````2(L]#J@``$B-;"0DZ'S]__](B>Y(C3UE2```B<,Q
MP.@I&```2(7`=&](BSWEIP``Z$C[___HL_S__TB+1"0H9$@K!"4H````#X68
M````2(/$.(G86UW#Z#'\__](B06RIP``2(G'2(7`=''HG?S__TB+!3:G``!D
M2(L0QH+7"0```.F__O__2(L]AZ<``.B*^___Z6C___](BSU^IP``2(7_=`KH
ME#0``.E[____2(T]@$<``$B)[NB0%P``2(D%6:<``$B)QTB%P`^$6?___^O2
MN`0```#I]_[__[\!````Z.?Z___HXOS__V:0\P\>^C'M28G17DB)XDB#Y/!0
M5$4QP#')2(T]T?W___\5PZ8``/1F+@\?A```````2(T]X:8``$B-!=JF``!(
M.?AT%4B+!5ZF``!(A<!T"?_@#Q^``````,,/'X``````2(T]L:8``$B--:JF
M``!(*?Y(B?!(P>X_2,'X`T@!QDC1_G042(L%):8``$B%P'0(_^!F#Q]$``##
M#Q^``````/,/'OJ`/6VF````=2M52(,]`J8```!(B>5T#$B+/3:F``#HN?G_
M_^AD____Q@5%I@```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````05=(
MB?Y,C4<X059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-
MC"2`````2(G7#Q^``````$&+`$V+$$B#QQ!)@\`(#\B)P$R)T4B)1_!,B=!(
MP>D@2,'H*$G!ZC@E`/\``$P)T$F)RDC!X0A)P>(8@>$``/\`18G23`G02`G(
M2(E'^$PYSW6M9@]O3"009@]O7"0@2(U$)&A(@<)H`@``9@]O5"0P9@]O+<>%
M```/'X``````\P]O`&8/;^)F#V]0V$B#P!!F#^](B&8/[\)F#^_!9@]OR&8/
M<]`?9@]S\0%F#^O!9@]ORV8/;]QF#]O%#RE`"$@YT'6[3(L.3(M>$$B+?B!(
MBUX83(G(3(G*2(MN"$B+3"0(2,'J&TC!X`5("=`#!"1(C8P+F7F"6HV4.)EY
M@EI,B=A(,=A((>A(,=B-/`)(B>I(B>A(P>@"2,'B'DF)^D@)PDR)V$G!ZAM!
MB=!,,<!,(<A,,=A(`<A(B?E(P>$%3`G13(M4)!!$C20(3(G(3(G)2,'I`DC!
MX!Y/C903F7F"6DV)Y4@)R$G![1M(,<*)P4@A^DPQPDP!TDV)XDG!X@5-">I,
MBVPD&$$!TDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=")UTPAX$G!
M[1M(,<A,`<!-B=!)P>`%30GH3(ML)"!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9
M>8):3`G@38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD*`'1
M3(G22<'J`DC!XAZ)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!
M^$B)STC!YP5,">],BVPD,`''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]
M2#'"2<'M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q,BVPD.$$!U$B)RDC!Z0)(
MP>(>18GD3XV4*IEY@EI("<I-B>5(,=!)P>T;B=%((?A,,<!,`=!-B>))P>(%
M30GJ3(ML)$!!`<)(B?A(P>\"2,'@'D6)TD^-A"B9>8):2`GX38G52#'"2<'M
M&XG'3"'B2#'*3`'"38G02<'@!4T)Z$R+;"1(00'03(GB2<'L`DC!XAY%B<!*
MC8PIF7F"6DP)XDV)Q4@QT$G![1M!B=1,(=!(,?A(`<A,B<%(P>$%3`GI3(ML
M)%`!P4R)T$G!Z@)(P>`>B<E*C;POF7F"6DP)T$F)S4@QPDG![1M!B<),(<),
M,>)(`?I(B<](P><%3`GO3(ML)%@!UTR)PDG!Z`)(P>(>B?]/C:0LF7F"6DP)
MPDF)_4@QT$G![1M!B=!((<A,,=!,`>!)B?Q)P>0%30GL3(ML)&!!`<1(B<A(
MP>`>2,'I`D6)Y$^-E"J9>8):2`G(38GE2#'"2<'M&XG!2"'Z3#'"3`'238GB
M2<'B!4T)ZDR+;"1H00'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@Q
MT$G![1N)UTPAX$@QR$P!P$V)T$G!X`5-">A,BVPD<$$!P$R)X$G![`)(P>`>
M18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)
MZ4R+;"1X`=%,B=)(P>(>2<'J`HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G2
M3"'`3#'@2`'X2(G/2,'G!4P)[TR+K"2``````<=,B<!)P>@"2,'@'HG_3XVD
M+)EY@EI,"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$:-+")(
MB<I(P>D"3(ND)(@```!(P>(>2`G*3XV4(IEY@EI-B>Q(,=!)P>P;B=%((?A,
M,<!,`=!-B>I)P>(%30GB3(ND))````!!`<)(B?A(P>`>2,'O`D6)TD^-A""9
M>8):2`GX38G42#'"2<'L&XG'3"'J2#'*3`'"38G02<'@!4T)X$6)P$P!PDV)
MZ$G![0))P>`>08G430GH3(NL))@```!,,<!,(=!*C8PIF7F"6DV)Y4@Q^$G!
M[1M(`<A,B>%(P>$%3`GIB<E(`<A,B=%)P>H"2,'A'D&)Q4P)T4V)PD6)P$DQ
MRD0QTDR+E"2@````2HV\%Z'KV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG22`'7
M3(GB2,'B'DG![`)!B?I,`X0DJ````$P)XDF)S(G)2`.,)+````!),=1$,>!-
MC:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)X$P)
MZ$F)U8G22`.4)+@```!),<5$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GY
MB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(B?I)
MB?I)P>H;2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<A(`X0DP```
M`(G)23'02`.,),@```!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)
M`<5(B?A(P>\"2,'@'D6)Z$@)^$B)UXG22`.4)-````!(,<=$,>=,C:0YH>O9
M;DR)P4R)QTC![QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`
M2`.$)-@```!),<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,
MB<))P>@"2,'B'D6)ZDP)PDF)R(G)23'02`.,).````!%,>!.C:0`H>O9;DR)
MT$V)T$G!Z!M(P>`%3`G`B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4
M).@```!(,<=$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)
MP>H"2,'A'D2)[TP)T4F)PHG`2`.$)/````!),<I%,>).C:02H>O9;DB)^DF)
M^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H
M3HVL`*'KV6Y,B=!-B=!(P>`%2<'H&T@#C"3X````3`G`B<!)`<5(B?A(P>\"
M2,'@'D6)Z$@)^$B)UXG22`.4)``!``!(,<=$,>=,C:0YH>O9;DR)P4R)QTC!
M[QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)`@!``!)
M,<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B
M'D6)ZDP)PDF)R(G)23'013'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P$@#
MC"00`0``B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4)!@!``!(,<=$
M,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)
M[TP)T4F)PHG`2`.$)"`!``!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%
M3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,
MB=!-B=!)P>@;2,'@!4P)P(G`20'%2(GX2,'@'DC![P)%B>A(`XPD*`$``$@)
M^$B)UXG22`.4)#`!``!(,<=$,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%3`GG
M38G42<'J`DG!Y!Z)_TT)U$F)PD@!^8G`33'BB<](`X0D.`$``$4QZDF)_4Z-
ME!*AZ]EN2(GZ2<'M&TC!X@5,">I!`=),B<))P>@"2,'B'D6)TDP)PDV)X$6)
MY$DQT$F)UD&)U40QP4V)T$B-C`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!2(GY
M2,'O`KC<O!N/2,'A'D@)^4D)SHG/2"'Z32'620G62(N4)$`!``!(`<),`>)-
MB<1,`?)-B<9)P>0%2<'N&TT)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G6
M08G222'^3"'!3`GQ3(NT)$@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)
M]4F)UD$!S4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)%`!
M``!)`<9,`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)
MXD@)T4F)UD&)U$TAQDPAZ4P)\4R+M"18`0``20'&30'R28G^3`'128GZ2<'N
M&TG!X@5-"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)
M\DR+M"1@`0``20'&30'P38G63`'"38G02<'@!4G![AM-"?!!`=!(B?I(P>\"
M2,'B'D6)P$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)&@!``!)`<9-`?1-B<9,
M`>%-B<1)P>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G108G*20G.
M32'&3"'23`GR3(NT)'`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!
MU4R)PDC!XAY)P>@"18GM3`G"2`G128G608G032'63"'A3`GQ3(NT)'@!``!)
M`<9,`?=-B>Y(`?E,B>])P>X;2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)_TP)
MX4&)S$D)SDTA[DPAXDP)\DR+M"2``0``20'&30'R28G^3`'228GZ2<'N&TG!
MX@5-"?)!`=),B>I)P>T"2,'B'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)\4R+
MM"2(`0``20'&30'P38G63`'!38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(P>\"
M2,'A'D6)P$@)^8G/20G.32'62"'Z3`GR3(NT))`!``!)`<9-`?1-B<9,`>)-
MB<1)P>X;2<'D!4T)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^
M3"'!3`GQ3(NT))@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!
MS4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)*`!``!)`<9,
M`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)
MUD&)U$TAQDPAZ4P)\4R+M"2H`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-
M"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"2P
M`0``20'&30'P38G63`'"38G02<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B'D6)
MP$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)+@!``!)`<9-`?1-B<9,`>%-B<1)
MP>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G120G.08G*32'&3"'2
M3`GR3(NT),`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDG!
MZ`)(P>(>18GM3`G"2`G128G008G732'03"'A3`G!3(N$),@!``!)`<!,`<=-
MB>A(`?E,B>])P>@;2,'G!4P)QT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)_$@)
M^4PAZ4PAXD@)RDB+C"30`0``2`'!3`'138G"2`.$)-@!``!(`<I,B<%)P>H;
M2,'A!4P)T8G)2`'*3(GI2<'M`DC!X1Y!B=),">E("<])B<U!B<Y,(<=-(>5)
M"?U*C3PX3(G03(N\)/@!``!,`>]-B=5(P>`%2<'M&TP)Z(G`2`''3(G`2<'H
M`DC!X!Y!B?U)"<"XUL%BRDPQP3'12(N4).`!``!(`<),`>)-B>Q(`<I,B>E)
MP>P;2,'A!4P)X4V)U(G)2<'D'D@!RDG!Z@))`<=-">)-B<2)T46)P$TQU$0Q
MYTR+I"3H`0``20'$30'T28G.3`'G28G,2<'N&TG!Y`5-"?1-B>Y)P>T"2<'F
M'D6)Y$T)]4R+M"3P`0``3`'G08G\20'&30'P38G633'N1#'R38GF20'03(GB
M2<'N&TC!X@5,"?*)TDD!T$B)RDC!Z0)(P>(>18G&2`G*1(G138GJ23'23`'Y
M3(N\)``"``!$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L
M`DC!X1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"00`@``13'H38G520'(3(G1
M2<'M&TD!QTC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)`@"``!)
M`<9,`?)-B>9),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J
M`DC!XAY!B?Y)"=)$B>))B<R)R4P!^DTQU$R+O"0@`@``13'@38GT20'03(GR
M2<'L&TD!QTC!X@5,">*)TDD!T$R)ZDG![0)(P>(>18G$3`GJ3(NL)!@"``!)
M`<5,`>E-B=5),=5$,>]-B>5(`<],B>%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N
M`DC!X1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"0P`@``13'038GJ20'(3(GI
M2<'J&TC!X05,"=&)R4D!R$R)X4C!X1Y)P>P"18G"20''3`GA3(ND)"@"``!)
M`<1,`>)-B?1),<Q$,>=-B=1(`==,B=))P>P;2,'B!4P)XHG22`'73(GJ2<'M
M`DC!XAY!B?Q)"=5$B?))B<Z)R4TQ[DP!^DR+O"1``@``13'P38GF20'03(GB
M2<'N&TC!X@5,"?*)TDD!T$R)TDG!Z@)(P>(>18G&3`G23(N4)#@"``!)`<),
M`=%-B>I),=)$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L
M`DC!X1Y!B?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"1@`@``13'H38G520'(3(G1
M2<'M&TC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)$@"``!)`<9,
M`?)-B>9%B>1),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J
M`DC!XAY!B?Y)"=)(BY0D4`(``$@!PDD!U$B)RHG)3#'220''1#'"38GP20'4
M3(GR2<'H&TC!X@5,"<*)TDD!U$R)ZDG![0)(P>(>18G@3`GJ3(NL)%@"``!)
M`<5,`>E-B=5),=5$,>]-B<5(`<],B<%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N
M`DC!X1Y!B?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"1P`@``13'B38GL3`'138GJ
M2<'L&TG!X@5-">)-B<1%B=))P>0>3`'12<'H`DD!QTT)X$R+I"1H`@``08G*
M20'$2`.$)'@"``!,`>)-B?1,`<A-,<1$,>=-B=1(`==,B=))P>P;2,'B!4P)
MXDV)[$G![0))P>0>B=)-">5%B?1-B<9(`==-,>Z)^DT!_$6)P$0Q\4F)UDP!
MP$V)Z$P!X4F)U$G![AM)P>0%30GT1`'A38G42<'J`DG!Y!Z)R4T)XDTQT$0Q
MQTF)R$@!^$B)STC!YP5)P>@;`>E!`=I,"<=$`VX@2(E."`'X3(E6&$B)!DB)
MT$C!Z@)(P>`>3(EN($@)T$0!V$B)1A!(BX0DB`(``&1(*P0E*````'422('$
MF`(``%M=05Q!74%>05_#Z(;E__]F#Q]$``!!5T%6055!5%532(/L"$B%_P^$
ML0```$B+!1*/``!,BS!-A?8/A)X````/M@=)B?])B?6$P'0$/#UU544QY$F+
M'DB%VW0P36/D3(GU#Q]``$R)XDR)_DB)W^A2X___A<!U!T*`/",]=$=(BUT(
M2(/%"$B%VW7:2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q!#[9$)`%)
M@\0!A,!T!#P]=>Y%*?SKE&8/'T0``$PI]4J-7",!2,']`T&);0#KM&8/'T0`
M`#';ZZH/'T``4TB)^TB![*````!D2(L$)2@```!(B80DF````#'`2(GFZ+KD
M__^%P'4VBU0D&('B`/```('Z`$```'0(@?H`H```=1Z^`@```$B)W^C_Y/__
MA<`/E,`/ML#K!P\?1```,<!(BY0DF````&1(*Q0E*````'4)2('$H````%O#
MZ"WD__]F9BX/'X0``````&:0055!5%532('LJ````&1(BP0E*````$B)A"28
M````,<!(A?]T"(`_`$B)^W4K2(N$))@```!D2"L$)2@````/A2,!``!(@<2H
M````6UU!7$%=PV8/'T0``.C#XO__2(G%2(7`=,A(B>_HH^3__TB%P`^$L@``
M`(!X$RY,C6`3=1!!@'PD`0!TW0\?A```````@'@3+@^$I@```$B)W^A>XO__
M3(GG28G%Z%/B__]!C7P%`DAC_^BFX?__38GA28G8O@$```!)B<5(B<<QP$C'
MPO____](C0U9+0``Z-#C__],B>](B>;H)>+__TR)[X/X_W00BT0D&"4`\```
M/0!```!T7>B(X?__3(GOZ.#A__](B>_H^./__TB%P`^%5?___P\?@`````!(
MB>_H<./__TB)W^AHX?__Z?#^__\/'P!!@'PD`2X/A4[___]!@'PD`@`/A`W_
M___I/?___P\?`.B;_O__ZZ'HM.+__P\?0`#S#Q[Z4TB+'82,``!(C0T=;0``
M2(TUL"P``$B+%7>,``!D2(L[Z$;C__]D2(L[3(T%3RX``%M(C17#%P``13')
M3(G!2(TUG"P``.F1X?__D$%505154TB![``0``!(@PPD`$B#[!BZ_P\``&1(
MBP0E*````$B)A"0($```,<!)B>1(B?M(B?5(C3UM+```3(GFZ*KA__^%P'X2
MB<&#Z`%(8]"`/!0`=4B%P'4\2(L%W8L``$B)ZDB)WF1(BSCH?N#__TB+A"0(
M$```9$@K!"4H````=4Y(@<08$```6UU!7$%=PP\?1```B<%F#Q]$``!,8^F^
M+P```$R)YTR)ZNB-W___2(7`=*1(BP6!BP``3(GI3(GB2(G>9$B+..@/X?__
MZY_HB.'__P\?A```````05=!5D%505152(GU4TB)^TB#["AD2(L$)2@```!(
MB40D&#'`,<"`/CT/E,!(`<5(B>_H*>#__TB-="042(G?28G$,<#HM_O__TB%
MP`^$!@$``$B)QTF)Q>@#X/__3#G@#X/2````2&-,)!1,BS6^B@``3(T\S0``
M```/M@.$P`^$HP$``#P]#X2;`0``2(G8#[90`4B#P`&$TG0%@/H]=>](*=A(
MF$V++DJ-?"`"Z`W?__]-`?U)B44`2(7`=%))BP9(C4L!2HL4.`^V`X@"/#UT
M(H3`=0WK'`\?@``````\/701#[8!2(/"`4B#P0&(`H3`=>O&`CTQP&8/'T0`
M``^V3`4`B$P"`4B#P`&$R77O2(M$)!AD2"L$)2@````/A1<!``!(@\0H6UU!
M7$%=05Y!7\,/'T``,<!F#Q]$```/ME0%`$&(5`4`2(/``832=>[KO0\?0`!,
MBS71B0``38L&28,X``^$PP```$R)P$4Q[68/'T0``$B#P`A$B>I!@\4!2(,X
M`'7OC7(#2&/V2,'F`XL%)XH``(7`=6-(B?=,B40D",<%$8H```$```#H#-[_
M_TB)QTB%P`^$4?___TECS4B+="0(3(T\S0````!,B?KH2-___TF)!DB)QT&-
M10%$B6PD%$B82,<$QP````#IA/[__V8N#Q^$``````!,B<?H*.#__TF)!DB)
MQTB%P`^$^O[__TECS4R-/,T`````Z[H/'T``,<#I=_[__[X0````13'MZ5?_
M___H/]___V9F+@\?A```````#Q]``/,/'OI(BP4%B0``2(L5!HD``$B-#9=I
M``!(C34J*0``9$B+..G'W___#Q^``````/,/'OI54TB![``0``!(@PPD`$B!
M[``0``!(@PPD`$B#["AD2(L$)2@```!(B80D&"```#'`2(V<)!`0``!(B>7H
M6]W__TB-#0XI``"Z`1```$B)WT&)P$R-#?@H``"^`0```#'`Z";?__^Z`!``
M`$B)[DB)W^@6WO__,<F%P'@NC7@!2(G#2&/_Z++<__](B<%(A<!T&$ACVTB)
M[DB)QTB)VN@YW___Q@08`$B)P4B+A"08(```9$@K!"4H````=0U(@<0H(```
M2(G(6UW#Z"W>__]F9BX/'X0``````&:0\P\>^ND7____#Q^``````/,/'OI!
M5T%6055!5%532('L`!```$B##"0`2('LN````&1(BP0E*````$B)A"2H$```
M,<!)B?Q(B?-(C3TW*```2(UT)`SH1?C__[XO````3(GG2(G%Z&7=__](A<!T
M0#'`3(GF2(T]%2@``.@?_/__3(G@2(N4)*@0``!D2"L4)2@````/A8(!``!(
M@<2X$```6UU!7$%=05Y!7\,/'P!(B=],C2WD)P``3(TUXR@``.@ZW?__3(GN
M2(G'Z&_=__](B<-(A<!TEX`[``^$Y````&8/'T0``$B%[7032(G>2(GOZ#C=
M__^%P`^$IP```$B)W^CXV___2(U4`_])B<=(.=-R%^LE9@\?A```````Q@(`
M2(/J`4@YTW0%@#HO=.](B=_HQ]O__TF)QTR)Y^B\V___28U$!P%(/?\/```/
MAQO___],C;PDH````$R)\4F)V#'`2(/L"+H`$```O@$```!,B?]!5$R-#2$G
M``#H+-W__TB-="0@3(G_Z'_;__]:687`=1"+1"0H)0#P```]`(```'1)3(GN
M,?_HC]S__TB)PTB%P`^$L_[__X`[``^%(O___TB%[70&@'T`+G070;\!````
M2(T=J"8``.E9____#Q]$``"`?0$`=+GKX;X!````3(G_Z,/<__^%P'6F3(G^
M2(T]AB8``.B0^O__3(G_Z.C;___I9_[__^C^V___9F8N#Q^$```````/'P#S
M#Q[Z4[XO````2(G[Z"[;__](C5`!2(7`2`]%VDB)WUOIJMO__V8N#Q^$````
M``#S#Q[Z55-(@>P`$```2(,,)`!(@^P89$B+!"4H````2(F$)`@0```QP$B%
M_P^$S@```(`_`$B)^P^$P@```.A=VO__2(U0`4B!^@`0```/A^0```!(B>5(
MB>^#^@AR#HG12(G>P>D#\TBE2(GS,<GVP@1T"8L+B0^Y!````/;"`G0.1`^W
M!`MF1(D$#TB#P0*#X@%T!P^V%`N(%`](C40%_T@YQ7(6ZQD/'X0``````,8`
M`$B#Z`%(.>AT!8`X+W3OOB\```!(B>_H0MK__TB%P'0M2#G%<EA(B>_HP-K_
M_TB+E"0($```9$@K%"4H````=4E(@<08$```6UW##Q\`2(N$)`@0``!D2"L$
M)2@```!U*4B!Q!@0``!(C3T%)0``6UWI>-K__P\?A```````Q@``ZZ,/'P`Q
MP.NDZ'_:__]F9BX/'X0```````\?0`#S#Q[Z05=!5D%505152(TMWB0``%-(
M@^P89$B+!"4H````2(E$)`@QP$B-7"0$9I`QP$B)WDB)[^BS]/__2(7`=#Y(
MBP77@P``2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(
M2(D02(72=?#KMF8/'T0``$B-+70D``!F#Q^$```````QP$B)WDB)[^A3]/__
M2(7`=#Y(BP5W@P``2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+
M4!!(@\`(2(D02(72=?#KMF8/'T0``$B-+1PD``!F#Q^$```````QP$B)WDB)
M[^CS\___2(7`=#Y(BP47@P``2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^`
M`````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-+<4C``!F#Q^$```````Q
MP$B)WDB)[^B3\___2(7`=#Y(BP6W@@``2&-4)`1(BP!(C0302(M0"$B)$$B%
MTG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-+6PC``!F#Q^$
M```````QP$B)WDB)[^@S\___2(7`=#Y(BP57@@``2&-4)`1(BP!(C0302(M0
M"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$R-)1PC
M``!F#Q^$```````QP$B)WDR)Y^C3\O__2(7`=#Y(BP7W@0``2&-4)`1(BP!(
MC0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0`
M`$R-)7$B``!F#Q^$```````QP$B)WDR)Y^AS\O__2(7`=#Y(BP67@0``2&-4
M)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D02(72=?#K
MMF8/'T0``$R--6@B``!F#Q^$```````QP$B)WDR)]^@3\O__2(7`=#Y(BP4W
M@0``2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(@\`(2(D0
M2(72=?#KMF8/'T0``$R-+1(B``!F#Q^$```````QP$B)WDR)[^BS\?__2(7`
M=#Y(BP77@```2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^``````$B+4!!(
M@\`(2(D02(72=?#KMF8/'T0``$R-/;PA``!F#Q^$```````QP$B)WDR)_^A3
M\?__2(7`=#Y(BP5W@```2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/#Q^`````
M`$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$R-/?H@``!F#Q^$```````QP$B)
MWDR)_^CS\/__2(7`=#Y(BP47@```2&-4)`1(BP!(C0302(M0"$B)$$B%TG3/
M#Q^``````$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B)WDB-/0,A``#HH?#_
M_TB%P'0-2(G&3(GO,<#HC_3__S'`2(G>2(T]\2```.A^\/__2(7`=!%(B<9(
MC3WO(```,<#H:/3__TB)WDB-/>D@```QP.A7\/__2(G&2(7`=#E,B><QP.A%
M]/__2(M$)`AD2"L$)2@```!U1$B#Q!A(B>](C373(```,<!;74%<05U!7D%?
MZ1;T__\QP$B)WDB-/:4@``#H!?#__TB%P'2[2(G&3(GW,<#H\_/__^NLZ&S5
M__]F9BX/'X0``````)#S#Q[Z2(/L&$B-/1`@``!D2(L$)2@```!(B40D"#'`
M2(UT)`3HM^___TB%P'0R#[80@/HP#Y3`A-(/E,()T(/P`0^VP$B+5"0(9$@K
M%"4H````=1!(@\08PP\?@``````QP.O@Z/?4__\/'X``````\P\>^E!82('L
MV````$B)="0H2(E4)#!(B4PD.$R)1"1`3(E,)$B$P'0W#RE$)%`/*4PD8`\I
M5"1P#RF<)(`````/*:0DD`````\IK"2@````#RFT)+`````/*;PDP````&1(
MBP0E*````$B)1"08,<!(C80DX````$B)^DB)X4B)1"0(2(U$)""^`0```$B)
M1"002(L%3GX``,<$)`@```!(BP#'1"0$,````$B)Q^A,T___O_\```#H,M+_
M_V:005154TR-G"0``/__2('L`!```$B##"0`3#G<=>](@^P0N@(````Q]F1(
MBP0E*````$B)A"0(``$`,<!!B?Q(B>/H6M3__TB-:/](B>I(P?H_2,'J,$B-
M1!4`#[?`2"G02"G%#XBK````#Q^``````#'22(GN1(GGZ"/4__](@_C_#X2D
M````N@@``0!(B=Y$B>?HN='__X/X_P^$?0```$B82(/X!W982(U$`_A(.=AR
M3DB-%9=]``#K#@\?1```2(/H`4@YV'(W2(L*2#D(=>](*=A(`>A(BY0D"``!
M`&1(*Q0E*````'5/2('$$``!`%M=05S#9BX/'X0``````$B![0```0!(@?T`
M`/__#X5<____2,?`_____^NZ2(T]1QX``#'`Z!7^__](C3TL'@``,<#H!_[_
M_^CRTO__9I#S#Q[Z2(/L".@CT___B<?HC-'__TB%P'0#2(L`2(/$",-F9BX/
M'X0```````\?0`#S#Q[Z055!5$R-)?@=``!52(G]3(GG4TB#[!AD2(L$)2@`
M``!(B40D"#'`2(UT)`3H"^W__TB%P'0(@#@`2(G#=2Y(BT0D"&1(*P0E*```
M``^%L````$B)[DB#Q!A,B><QP%M=05Q!7>G3\/__#Q\`2(GN2(G'Z+71__](
MA<!T($B+1"0(9$@K!"4H````=79(@\086UU!7$%=PP\?1```2(GOZ/C0__](
MB=])B<7H[=#__TF-?`4"Z$/0__](@^P(28GHO@$```!32,?"_____TB)QTF)
MQ4R-#6`<``!(C0U?'0``,<#H9-+__UA:2(M$)`AD2"L$)2@```!U"$R)[NE3
M____Z+71__\/'T0``/,/'OI!5TB-%0$=``!(C0V5'```059F2`]NPDB-%:0<
M``!)B?Y!54B-/>H;``!!5%532('L.`$``&1(BP0E*````$B)A"0H`0``2(T%
MQ1L``$B-;"042,=$)%``````2,>$)(@`````````2(GN2,=$)#``````9D@/
M;LA(C060'```9@]LP69(#V[02(T%B!P```\I1"1`9D@/;L%F2`]NV$B-#78<
M``!F#VS"2(T%<!P```\11"1H9D@/;L)F2`]NX#'`9@]LPP\11"1X9D@/;L%F
M#VS$#RE$)"#H3^O__TB%P'0,@#@`2(G##X66!```Z/G0__^)Q^ABS___2(7`
M#X3I`P``3(L@387D#X3=`P``3(GGZ'7/__](C7P``>C+SO__10^V!"1)B<=(
MB<-%A,!T.DR-+?$;```/'T``10^VP$R)_TR)Z;X!````2,?"_____S'`28/$
M`4F#QP+HV]#__T4/M@0D183`==%,C6PD8$B-/34;``#K$`\?`$F+?0A)@\4(
M2(7_=#-(B>XQP.B9ZO__28G$2(7`=.&`.`!TW$B)Q^A4Z___A<!TT$R)Y^C8
MS___28G'2(7`=4!,C60D0$V+/"1-A?]T,D&`/P`/A`@#``!,B?_H(.O__X7`
M#X4(`0``38M\)`A)@\0(387_==AF+@\?A```````3(G_Z(C.__](B=])B<3H
M?<[__T6-I`0$!```36/D3(GGZ,K-__]338GX3(T-_QD``$F)Q4B-!0`;``"^
M`0```$C'PO____]02(T-XQH``$R)[S'`Z.?/__],B>^^P`$``.A*T/__7T%8
M@_C_=1+H#<___T2+"$&#^1$/A=T"``!(C80DD````$R)[TB)QDB)!"3H2<__
M_XG#A<!T<TB+!01Y``!)BPY-B>A(C14_&P``O@$```!(BS@QP.C@S/__13'D
M2(N$)"@!``!D2"L$)2@````/A0<$``!(@<0X`0``3(G@6UU!7$%=05Y!7\.0
M3(G_28/$".B4SO__28G'2(7`#X2]_O__Z?/^__\/'P"+A"2H````)0#P```]
M`$````^%=O___T2+O"2L````Z+S.__]!.<</A6#___^+A"2H````)?\!```]
MP`$```^%2?___TR)Y^B4S/__2(GN2(T]G!D``$F)Q#'`Z,#H__](A<`/A$<"
M``!)BSY(B<;H'/#__TF)QTB%P`^$,`(``$R)_^CXS/__2(G"@_@#?D!(F$B-
M-9<9``!(B50D"$F-?`?\Z`C.__^%P'4D2(M4)`B#^@0/A-P"``"-0OM(F$&`
M/`<O#X3,`@``9@\?1```2(GN2(TMA1@``#'`2(GOZ#SH__](A<`/A-,!```/
MM@"$P`^$R`$``#PP#X3``0``2(GO2(TUPA@``#'`Z`_L__](C2U<&0``3(TU
M0QD``.@<S/__54C'PO____]-B>A03(T-Z1<``+X!````3(GG2(T-#AD``#'`
MZ./-__]86NM'#Q^``````.@3S?__@S@1=4CHV<O__X/#`4B#[`A-B>A53(T-
MIQ<``$R)\;X!````4TC'PO____],B>=0,<#HG,W__TB#Q""^P`$``$R)Y^C[
MS?__@_C_=*Y,B>_HOLO__TR)YDB-/4P7```QP.A=Z___3(GGZ!7Z___IX_W_
M_T4Q_^D8_?__#Q^$``````!(BWPD($B-7"0@2(7_="*0,<!(B>[H)N?__TB%
MP'0%@#@`=31(BWL(2(/#"$B%_W7?OPT```!,C27:%P``Z+[*__]!N%,```!)
MB<=(B</I\OO__P\?1```2(G'Z$#,__])B<1(A<!TO.FV^___2(L%1'8``$F+
M#DV)Z$B-%3\8``"^`0```$B+.#'`Z"#*___I._W__P\?`$B)Q^A@^?__2(N$
M)"@!``!D2"L$)2@````/A3H!``!(@<0X`0``2(G?6UU!7$%=05Y!7^G0R___
M38L^Z<C]__\/'X0``````#'V3(G_,<#H-,O__T&)QH7`#X0I_O__B<?HDO?_
M_TF)QTB%P`^(%O[__S'22(UP]D2)]^@8S/__2(UT)!JZ!@```$2)]^BVR?__
M2(/X!@^%P@```(%\)!H`0T%##X7>_?__9H%\)!Y(10^%T?W__S'228UWSD2)
M]^C3R___2(L<)+HH````1(GW2(G>Z&_)__](@_@H=7](C046%P``O@$```!-
MB>A,B>?&A"2X`````$B-#<T6``!,C0VA%0``2,?"_____U`QP%/HH<O__UE>
MZ13^__]-BW8(387V#X0M_?__3(GWZ-7)__](@_@##X8;_?__28U\!OQ(C35T
M%@``Z.K*__^%P$T/1/[I__S__^C*RO__2(T]718``#'`Z,SU__]F9BX/'X0`
M`````)#S#Q[Z051(C3U&%0``55-(@^P02(L==G0``&1(BP0E*````$B)1"0(
M,<!,C60D!$R)YF1(BRL/MH6P````B(6Q````,<#HYN3__TB%P'0)@#@Q#X1H
M`0``,<#HX>___V1(BRM(B>^Y`P```+H!````2(TU#!8``.B4R/__2(G%2(7`
M="A(BT`09$B+.TB-%?(5``!(BS#HI<C__TB+11!(BS#V1@Y`#X5$`0``9$B+
M.[D#````N@$```!(C37)%0``Z$K(__](B<5(A<!T+4R)YDB-/4D4```QP.A1
MY/__2(G"2(7`#X3E````2(M%$&1(BSM(BS#H1<C__V1(BSNZ`0```$B--8$5
M``#H8,?__V1(BSM(C16&%0``2(G&Z!W(__]D2(L#3(GF2(T]YQ,``,:`L0``
M```QP.CQX___2(D%NG,``$B)PTB%P'1"OL`!``!(B=_H5<K__XU0`8/Z`78)
M@_@1#X62````2(M$)`AD2"L$)2@````/A9L```!(@\006UU!7,,/'X``````
M2(L]<7,``.AD]___2(D%77,``$B)PTB%P'6C2(T]EA4``#'`Z$?)__\/'X``
M````@'@!``^$F?[__^F)_O__D$B+!3%S``!(BS!(BT402(LXZ&KF___I$/__
M_P\?1```9$B+.^BGR/__Z:[^__^)P4B+!0%S``!(B=I(C3U?%0``2(LP,<#H
MY<C__^B0R/__\P\>^E5(B?U32(/L&&1(BP0E*````$B)1"0(,<#HKNS__[XO
M````2(G'2(G#Z*['__](A<!(C5`!2`]%VDB)W^@KR/__2(UT)`1(C3W^$@``
M2(G#,<#HM>+__TB%P'0@#[80A-(/E,"`^C`/E,((T'4.2(7M=`F`?0``=2,/
M'P!(BT0D"&1(*P0E*````'5&2(/$&%M=PV8/'X0``````+H$````2(TU;Q,`
M`$B)W^@,QO__A<!UR$B+1"0(9$@K!"4H````=0Y(@\082(GO6UWIFN/__^BU
MQ___#Q]$``#S#Q[Z2(/L"+^`````Z-[%__]F#V\%-E(``$C'0#``````#Q$`
M9@]O!3-2``#'0'@`````#Q%`$&8/;P4P4@``#Q%`($B#Q`C##Q^``````/,/
M'OI!5TACPD%628G&055!5$F)_%5(C6\X4TB)\TB#[`A(BW<H2(M7,(T,QD@Y
M\4B)3RA(@](`2,'H'4@!T$B)1S!(8T=XA<`/A>D```!!@_X_#XXG`0``08/N
M0$6)]T'![P9%C6\!2<'E!DD!W9#S#V\#3(GG2(/#0`\110#S#V]+T`\131#S
M#V]3X`\152#S#V];\`\173#HT<K__TPYZW7,0<'G!D4I_DECQDB#^`AR7$F+
M50!)C4PD0$B#X?A)B50D.$F+5`7X2(E4!?A(*<U(`>A)*>U(@^#X2(/X"'(8
M2(/@^#'228MT%0!(B3012(/""$@YPG+N18ET)'A(@\0(6UU!7$%=05Y!7\.0
MJ`1U=$B%P'3B00^V50!!B%0D.*@"=-1!#[=4!?YFB50%_NO'#Q]``$&_0```
M`$B-?`4`2(G>02G'13GW10]/_DUC[TR)ZNCEQO__08M$)'A$`?A!B40D>(/X
M0'633(GG12G^3`'KZ/7)___IS_[__TF)W>DC____08M5`$&)5"0X08M4!?R)
M5`7\Z5S___^0\P\>^D%63(UV.$%505152(G]4TR+;BA(B?-,BV8P3(GH2,'H
M`X/@/XU0`<9$!CB`2&/*@_HX#XZ$`0``OD````!,`?$IUG0/,<")PH/``<8$
M$0`Y\'+S2(G?Z'')__]F#^_`#Q%#.$G'1C``````00\11A!!#Q%&($R)XD$/
MML5,B>],B>Y(P>H82,'@"$R)X4C![Q!)B=!,B>I(P>X8#[;60`^V_T`/MO9(
MP>D02`G03(GB#[;)2,'@"$@)^`^V_D$/MM!(P>`(2`GP00^V]$C!X`A("?!(
MP>`(2`GX2(G?2,'@"$@)R$C!X`A("=!(B4-PZ-C(__](BP-(B=](P>@8B$4`
M2(L#2,'H$(A%`4B+`XAE`DB+`XA%`TB+0PA(P>@8B$4$2(M#"$C!Z!"(105(
MBT,(B&4&2(M#"(A%!TB+0Q!(P>@8B$4(2(M#$$C!Z!"(10E(BT,0B&4*2(M#
M$(A%"TB+0QA(P>@8B$4,2(M#&$C!Z!"(10U(BT,8B&4.2(M#&(A%#TB+0R!(
MP>@8B$402(M#($C!Z!"(11%(BT,@B&422(M#((A%$UM=05Q!74%>Z=C"__\/
M'X0``````+@X````20'.,?\IT(/X"')'28U."(G"2<<&`````$G'1!;X````
M`$B#X?A)*<Y$`?"#X/B#^`@/@GS^__^#X/@QTHG6@\((2(D\,3G"<O/I9?[_
M_P\?0`"H!'4DA<`/A%7^__]!Q@8`J`(/A$G^__\QTF9!B50&_ND\_O__#Q\`
M0<<&`````$''1`;\`````.DD_O__9BX/'X0``````)#S#Q[Z2(L-;6T``.E@
MP?__\P\>^DB#[`A(@\0(PP``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````$``@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O<V5L9B]E>&4`+W!R;V,O)6DO
M)7,`+@!005)?5$5-4`!005)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,
M24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%
M1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%
M0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]4
M14U0`%!!4E]'3$]"04Q?0TQ%04X`,0!L<V5E:R!F86EL960`<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%53
M15(`55-%4DY!344`)3`R>``E<R5S)7,E<P!P87(M`'!A<FP`+G!A<@!S:&]R
M="!R96%D`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U.0`M
M90`M+0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T
M<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T;R!C<F5A=&4@8V%C
M:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C
M86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````
M``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@
M7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O9F9S971?<VEZ92P@
M)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-04=)0R`](")<;E!!
M4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@(",@<&%C:R@B3B(I
M"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!1TE#(#T@(E!+7#`P
M,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D9F@I(#T@0%\[
M"FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F.PIM>2`D<VEZ
M92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M("@D<VEZ92TQ*2`E
M("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I<R!A(&UU;'1I<&QE
M(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I('L*<V5E:R`D9F@L
M("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T
M:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%2
M7TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I.PI]"B1P;W,@+3T@
M)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D
M14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D
M:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S
M*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I
M;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]
M+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E
M;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z
M.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*
M54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE
M.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P
M(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E
M;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W
M,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L
M;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K
M9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E<WES
M(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@
M)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC
M>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M
M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T
M7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%35!](#T@(B1%3E9[
M4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T87)T7V]F7T9)3$5?
M<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D<')O9VYA;64I('L*
M;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R;V=N86UE(ETI.R`@
M(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E<R!%<G)N;RYP;0IL
M87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M86=I8R@J
M7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H<7%;0V%N)W0@9FEN
M9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I;&4@(B1P<F]G;F%M
M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!005(@;6%G:6,@870@
M<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M
M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!0TA%(BDL(#`["G)E
M860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@;F4@
M(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2!["F]U=',H(DYO(&-A
M8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]"F]U=',H<7%;0V%C
M:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&2"P@)&UA9VEC7W!O
M<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&2"P@)&)U9BP@)$9)
M3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A8VLH(DXB+"`D8G5F
M*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,17,@:7,@)&]F9G-E
M="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE
M("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C=&EO;B`]('1E;&P@
M7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@
M("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I<G-T(")&24Q%
M(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE
M(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D
M8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65]
M(#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M
M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97TK*SL*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD;6]D=6QE?3L*<F5T
M=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E7VQI<W1[)&UO9'5L
M97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*
M:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE
M=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B
M0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*
M)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD:6YF;RT^>V9I;&5]
M(#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&5N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B.B`D(5T["G)E='5R
M;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N)W0@9FEN
M9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E
M<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR
M97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N
M86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@
M*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N
M86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]
M?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+6DE07TU!1TE#*2![
M"F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F
M:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@
M/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z
M:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L
M("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@
M<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF
M("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G
M("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?
M<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG
M;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP
M72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2
M155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B
M96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'
M5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII
M9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@
M)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD
M;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@
M)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L
M<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I
M92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H
M)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I
M.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[
M)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$
M:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@
M0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@
M24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S
M=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF
M("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@
M;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN
M9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*
M:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N
M>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O
M7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*
M?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@
M)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A
M73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@
M:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q("102UI)4%]-04=)
M0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)
M3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z
M.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP*
M*2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O=70B.B`D(5T["B1F
M:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<CL*:68@
M*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@>PIR96%D(%]&2"P@
M)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*?2!E;'-E('L*;&]C
M86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@
M>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"B1F:"T^<')I;G0H
M)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D
M;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO
M('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF
M:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O
M<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA
M3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L
M:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@
M6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I
M.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L
M<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>
M7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D
M,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI
M)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O
M)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T
M.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A
M8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#
M86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO
M<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N
M="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@
M)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP
M.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L
M96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;
M5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW
M<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*
M?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R:6YT*")<,$-,14%.
M(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?;F%M92D@>PIM>2`D
M8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D9F@L(#`L(#`["B1C
M='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#(["B1C86-H95]N86UE
M(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD8V%C:&5?;F%M92`N
M/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG=&@@)&-A8VAE7VYA
M;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#04-(12(I.PI]"FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BD["B1F:"T^
M<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!1TE#*3L*)&9H+3YC
M;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I;&5R(&]F("(D;W5T
M(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@24\Z.DAA;F1L90HD
M9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@<7%;9F1O<&5N
M*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE*"US
M(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z:7`@87)C
M:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B1005(Z
M.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S*")%>'1R86-T:6YG
M('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D;65M8F5R
M("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C
M=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA;64["FYE
M>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E
M;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE
M('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T;R`B)&1E<W1?;F%M
M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B
M.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N
M<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R
M;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN
M"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H
M0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@
M)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN
M+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H
M*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@
M97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E
M<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T
M<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E
M($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U
M:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ
M4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I
M<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP
M<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG
M97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E
M<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I
M<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E
M(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q
M=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*
M979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@
M>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R
M97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PIE=F%L
M('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R7W1E;7`@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX["GT*9F]R96%C:"!M
M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?5$U01$E2(%1-4$1)
M4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%35`@+W1M<"`N("D*
M*2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD("UD("1P871H(&%N
M9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U:60["F5V86P@>R@D
M<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*:68@*"!D
M969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S97)N86UE(#T@)E=I
M;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@)'!W=6ED*2!["B1U
M<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*?0IM>2`D<W1M
M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D
M=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;7D@)&-A8VAE7V1I
M<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?9&ER(#T@(G1E;7`M
M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["FEF("@H
M;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F:"DI(#X](#`I('L*
M<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE
M;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F
M:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD
M8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF
M("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6
M>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD
M8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%
M35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.
M5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS
M=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@
M*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q
M<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E
M+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M
M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@
M)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`[
M"FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6
M>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N
M86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*
M:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D
M<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P
M<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N
M86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y
M<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B
M)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G
M;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF
M("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX
M7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.
M04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I
M('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY
M("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H
M*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D
M*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]
M7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?
M96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR
M971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*
M9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.
M04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@
M)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/
M0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6
M>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970[
M"FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*
M<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF
M:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N
M9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*
M<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!
M4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP
M87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO
M('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M
M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)2
M3U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/
M4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF
M("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``<&5R;'AS:2YC````
M`````/____\`````_____P`````!(T5G`````(FKS>\`````_MRZF`````!V
M5#(0`````/#ATL,````````````````!&P,[!`$``!\```!@;___.`$``-!R
M__]@`0``X'+__W@!``!`=O__H`8``%!X__\@`0``0'G__Y`!``"PC___X`$`
M`("0__\L`@``$)'__U`"``"`DO__C`(``-"2__^H`@``L)/__^@"````EO__
M-`,``#"6__](`P``$)?__WP#```@E___D`,``$"9___T`P``<)G__Q`$``#`
MFO__3`0``-"?__^8!```0*#__[0$````H?__T`0``$"B__\0!0``<*+__R@%
M``"`H___A`4``("J__\T!@``H*S__V@&``"`K?__S`8``-"M___D!@``<*__
M_S`'``#0L?__<`<````````4``````````%Z4@`!>!`!&PP'")`!```4````
M'````"AW__\F`````$0'$``````D````-````"!N__]P`P````X01@X82@\+
M=PB``#\:.2HS)"(`````%````%P```!H<?__$```````````````%````'0`
M``!@<?__8`,`````````````3````(P```"H=___:A8```!"#A"/`DD.&(X#
M0@X@C01"#BB,!4$.,(8&00XX@P='#M`%`T(6"@XX00XP00XH0@X@0@X80@X0
M0@X(00L```!(````W````,B-___,`````$(.$(\"0@X8C@-"#B"-!$(.*(P%
M00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`(````"@!
M``!,CO__@P````!!#A"#`DH.L`$"<0H.$$$."$$+.````$P!``"XCO__;`$`
M``!"#A"-`D(.&(P#00X@A@1!#BB#!4<.T`%^"@XH00X@00X80@X00@X(1PL`
M&````(@!``#LC___3P````!%#A"#`G$."````#P```"D`0``()#__]@`````
M0@X0C0)"#AB,`T$.((8$00XH@P5'#J@@20[`(`)V"@XH00X@00X80@X00@X(
M1@M(````Y`$``,"0__]!`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$
M#CB#!T<.8`,5`0H..$$.,$$.*$(.($(.&$(.$$(."$4+$````#`"``#$DO__
M*0`````````P````1`(``."2___3`````$4.$(8"00X8@P-'#I@@3`Z80$D.
MP$`"I@H.&$0.$$$."$$+$````'@"``",D___"0````````!@````C`(``(B3
M__\2`@```$8.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.N"!,#O`A
M`G$*#CA!#C!!#BA"#B!"#AA"#A!"#@A$"P*Y#O@A3PZ`(EH.^"%!#O`A````
M&````/`"``!$E?__)@````!%#A"#`EP."````#@````,`P``6)7__T$!````
M10X0A@)!#AB#`T<.F"!)#K`@`N0*#AA!#A!!#@A$"UH*#AA(#A!!#@A-"T@`
M``!(`P``;);__P0%````1@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D@..(,'
M1`Y0`Z8$"@XX30XP00XH0@X@0@X80@X00@X(10L8````E`,``#";__]I````
M`$@.(`)0"@X(2`L`&````+`#``"$F___O@````!%#A!!#@A'#N`!`#P```#,
M`P``*)S__SX!````0@X0C`)!#AB&`T$.((,$2`P+H(`$40T'1`ZP@`0"T`H.
M($$.&$$.$$(."$L+```4````#`0``"B=__\A`````$@.$%@."`!8````)`0`
M`$"=__\+`0```$8.$(T"0@X8C`-(#B"&!$<.*(,%1`Y``D(*#BA&#B!!#AA"
M#A!"#@A("V0*#BA!#B!!#AA"#A!"#@A&"V$.2$D.4&,.2$$.0````*P```"`
M!```])W___0&````1@X0CP)0#AB.`U$.((T$20XHC`5!#C"&!D$..(,'1P[P
M`@/N`0[X`F$.@`-?#O@"0@[P`@)X"@XX1`XP00XH0@X@0@X80@X00@X(0@L#
M10$.^`)+#H`#7@[X`D$.\`)?#O@"1`Z``U`.B`-+#I`#2P[P`@,&`0H..$0.
M,$$.*$(.($(.&$(.$$(."$4+`M<.^`)##H`#1@[X`D$.\`(`,````#`%``!$
MI/__(`(```!&#A",`D@.&(8#00X@@P1$#C`#<0$*#B!!#AA!#A!"#@A("S0`
M``!D!0``,*;__]L`````10X0A@)$#AB#`T0.,`*'"@X800X000X(2@ML"@X8
M1`X000X(10L`*````)P%``"8;___#@(```!%#A"&`D$.&(,#1`Y0`VL!"@X8
M0PX000X(00L4````R`4``*RF__])`````$@.$`)`#@A(````X`4``.2F__^?
M`0```$8.$(\"10X8C@-%#B"-!$(.*(P%1`XPA@9%#CB#!T<.0`+B"@XX00XP
M00XH0@X@0@X80@X00@X(0@L`/````"P&```XJ/__50(```!&#A".`D8.&(T#
M0@X@C`1!#BB&!40.,(,&`YD!"@XH00X@0@X80@X00@X(30L``!````!L!@``
M6*K__Q``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````\"D```````"P*0````````$`````````W`(````````!
M`````````.P"````````#```````````(`````````T`````````H&(`````
M```9`````````,C+````````&P`````````(`````````!H`````````T,L`
M```````<``````````@`````````]?[_;P````"P`P````````4`````````
M8`T````````&`````````)`$````````"@````````!U!`````````L`````
M````&``````````5`````````````````````P````````#8S0````````(`
M````````$`4````````4``````````<`````````%P````````"8%```````
M``<`````````&!,````````(`````````(`!````````"0`````````8````
M`````!X`````````"`````````#[__]O``````$```@`````_O__;P````"8
M$@```````/___V\``````0````````#P__]O`````-81````````^?__;P``
M```$````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
MV,L`````````````````````````````,"````````!`(````````%`@````
M````8"````````!P(````````(`@````````D"````````"@(````````+`@
M````````P"````````#0(````````.`@````````\"``````````(0``````
M`!`A````````("$````````P(0```````$`A````````4"$```````!@(0``
M`````'`A````````@"$```````"0(0```````*`A````````L"$```````#`
M(0```````-`A````````X"$```````#P(0`````````B````````$"(`````
M```@(@```````#`B````````0"(```````!0(@```````&`B````````<"(`
M``````"`(@```````)`B````````H"(```````"P(@```````,`B````````
MT"(```````#@(@```````/`B`````````",````````0(P```````"`C````
M````,",```````!`(P```````%`C````````8",```````!P(P```````(`C
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````(T`````````I005(N<&T*``````````#X
M<@```````$=#0SH@*%5B=6YT=2`Q,RXR+C`M-G5B=6YT=3$I(#$S+C(N,```
M+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E+F=N
M=2YB=6EL9"UI9``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N9'EN<WEM`"YD
M>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N
M<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G!L="YS96,`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N
M9FEN:5]A<G)A>0`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````````````````
M````````````````````"P````$````"`````````!@#````````&`,`````
M```<`````````````````````0```````````````````!,````'`````@``
M```````X`P```````#@#````````,`````````````````````@`````````
M```````````F````!P````(`````````:`,```````!H`P```````"0`````
M```````````````$````````````````````.0````<````"`````````(P#
M````````C`,````````@````````````````````!```````````````````
M`$<```#V__]O`@````````"P`P```````+`#````````X``````````&````
M``````@```````````````````!1````"P````(`````````D`0```````"0
M!````````-`(````````!P````$````(`````````!@`````````60````,`
M```"`````````&`-````````8`T```````!U!````````````````````0``
M`````````````````&$```#___]O`@````````#6$0```````-81````````
MO``````````&``````````(``````````@````````!N````_O__;P(`````
M````F!(```````"8$@```````(``````````!P````$````(````````````
M````````?0````0````"`````````!@3````````&!,```````"``0``````
M``8`````````"``````````8`````````(<````$````0@````````"8%```
M`````)@4````````$`4````````&````&`````@`````````&`````````"1
M`````0````8``````````"``````````(````````!L`````````````````
M```$````````````````````C`````$````&`````````"`@````````("``
M``````!P`P``````````````````$``````````0`````````)<````!````
M!@````````"0(P```````)`C````````$````````````````````!``````
M````$`````````"@`````0````8`````````H",```````"@(P```````&`#
M```````````````````0`````````!``````````J0````$````&````````
M```G`````````"<```````"@.P``````````````````$```````````````
M`````*\````!````!@````````"@8@```````*!B````````#0``````````
M``````````0```````````````````"U`````0````(``````````'``````
M````<````````,!````````````````````0````````````````````O0``
M``$````"`````````,"P````````P+`````````$`0``````````````````
M!````````````````````,L````!`````@````````#(L0```````,BQ````
M````@`8```````````````````@```````````````````#5````#@````,`
M````````R,L```````#(NP````````@````````````````````(````````
M``@`````````X0````\````#`````````-#+````````T+L````````(````
M````````````````"``````````(`````````.T````&`````P````````#8
MRP```````-B[``````````(````````'``````````@`````````$```````
M``";`````0````,`````````V,T```````#8O0```````"@"````````````
M```````(``````````@`````````]@````$````#``````````#0````````
M`,`````````H````````````````````"````````````````````/P````(
M`````P`````````HT````````"C`````````*`````````````````````@`
M```````````````````!`0```0```#`````````````````````HP```````
M`"4````````````````````!``````````$``````````0````,`````````
M````````````````3<`````````*`0```````````````````0``````````
'````````````
